==> huaweicloudsdkdataartsstudio-3.1.134-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/fgac_update_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class FgacUpdateReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'fgac_ids': 'list[FgacSingleUpdateReq]'
    }

    attribute_map = {
        'fgac_ids': 'fgac_ids'
    }

    def __init__(self, fgac_ids=None):
        """FgacUpdateReq

        The model defined in huaweicloud sdk

        :param fgac_ids: 细粒度认证数据开发连接列表
        :type fgac_ids: list[:class:`huaweicloudsdkdataartsstudio.v1.FgacSingleUpdateReq`]
        """
        
        

        self._fgac_ids = None
        self.discriminator = None

        if fgac_ids is not None:
            self.fgac_ids = fgac_ids

    @property
    def fgac_ids(self):
        """Gets the fgac_ids of this FgacUpdateReq.

        细粒度认证数据开发连接列表

        :return: The fgac_ids of this FgacUpdateReq.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.FgacSingleUpdateReq`]
        """
        return self._fgac_ids

    @fgac_ids.setter
    def fgac_ids(self, fgac_ids):
        """Sets the fgac_ids of this FgacUpdateReq.

        细粒度认证数据开发连接列表

        :param fgac_ids: The fgac_ids of this FgacUpdateReq.
        :type fgac_ids: list[:class:`huaweicloudsdkdataartsstudio.v1.FgacSingleUpdateReq`]
        """
        self._fgac_ids = fgac_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FgacUpdateReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/fgac_update_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class FgacUpdateReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'fgac_ids': 'list[FgacSingleUpdateReq]'
    }

    attribute_map = {
        'fgac_ids': 'fgac_ids'
    }

    def __init__(self, fgac_ids=None):
        r"""FgacUpdateReq

        The model defined in huaweicloud sdk

        :param fgac_ids: 细粒度认证数据开发连接列表
        :type fgac_ids: list[:class:`huaweicloudsdkdataartsstudio.v1.FgacSingleUpdateReq`]
        """
        
        

        self._fgac_ids = None
        self.discriminator = None

        if fgac_ids is not None:
            self.fgac_ids = fgac_ids

    @property
    def fgac_ids(self):
        r"""Gets the fgac_ids of this FgacUpdateReq.

        细粒度认证数据开发连接列表

        :return: The fgac_ids of this FgacUpdateReq.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.FgacSingleUpdateReq`]
        """
        return self._fgac_ids

    @fgac_ids.setter
    def fgac_ids(self, fgac_ids):
        r"""Sets the fgac_ids of this FgacUpdateReq.

        细粒度认证数据开发连接列表

        :param fgac_ids: The fgac_ids of this FgacUpdateReq.
        :type fgac_ids: list[:class:`huaweicloudsdkdataartsstudio.v1.FgacSingleUpdateReq`]
        """
        self._fgac_ids = fgac_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FgacUpdateReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
